==> cozy-ui-122.11.1.tgz: package/transpiled/react/providers/CozyTheme/DumbCozyTheme.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import { CozyThemeContext } from "cozy-ui/transpiled/react/providers/CozyTheme/index";
import MuiCozyTheme from "cozy-ui/transpiled/react/MuiCozyTheme";
import { isTwakeTheme } from "cozy-ui/transpiled/react/helpers/isTwakeTheme";
import useMediaQuery from "cozy-ui/transpiled/react/hooks/useMediaQuery";

var DumbCozyTheme = function DumbCozyTheme(_ref) {
  var _cx;

  var variant = _ref.variant,
      className = _ref.className,
      ignoreItself = _ref.ignoreItself,
      settingsThemeType = _ref.settingsThemeType,
      children = _ref.children;
  var uiThemeType = localStorage.getItem('ui-theme-type'); // use only for cozy-ui documentation and argos screenshots

  var uiThemeVariant = localStorage.getItem('ui-theme-variant'); // use only for cozy-ui documentation and argos screenshots

  var uiThemeName = isTwakeTheme() ? 'Twake' : 'Cozy';
  var deviceThemeType = useMediaQuery('(prefers-color-scheme: dark)') ? 'dark' : 'light';
  var filteredSettingsThemeType = ['light', 'dark'].includes(settingsThemeType) ? settingsThemeType : undefined;
  var selfThemeType = uiThemeType || filteredSettingsThemeType || deviceThemeType;
  var selfThemeVariant = uiThemeVariant || variant;
  return /*#__PURE__*/React.createElement(CozyThemeContext.Provider, {
    value: {
      type: selfThemeType,
      variant: selfThemeVariant,
      name: uiThemeName,
      isLight: selfThemeType === 'light'
    }
  }, /*#__PURE__*/React.createElement(MuiCozyTheme, {
    type: selfThemeType,
    variant: selfThemeVariant
  }, /*#__PURE__*/React.createElement("div", {
    className: cx(className, (_cx = {}, _defineProperty(_cx, "".concat(uiThemeName, "Theme--").concat(selfThemeType, "-").concat(selfThemeVariant), Boolean(selfThemeVariant)), _defineProperty(_cx, 'u-dc', ignoreItself), _cx))
  }, children)));
};

DumbCozyTheme.propTypes = {
  variant: PropTypes.oneOf(['normal', 'inverted']),

  /** Causes this element's children to appear as if they were direct children of the element's parent, ignoring the element itself. */
  ignoreItself: PropTypes.bool,
  className: PropTypes.string,

  /** Theme type from io.cozy.settings.instance */
  settingsThemeType: PropTypes.oneOf(['light', 'dark', 'auto']),
  children: PropTypes.node
};
export default DumbCozyTheme;

==> cozy-ui-124.0.0.tgz: package/transpiled/react/providers/CozyTheme/DumbCozyTheme.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';
import { CozyThemeContext } from "cozy-ui/transpiled/react/providers/CozyTheme/index";
import MuiCozyTheme from "cozy-ui/transpiled/react/MuiCozyTheme";
import useMediaQuery from "cozy-ui/transpiled/react/hooks/useMediaQuery";

var DumbCozyTheme = function DumbCozyTheme(_ref) {
  var _cx;

  var variant = _ref.variant,
      className = _ref.className,
      ignoreItself = _ref.ignoreItself,
      settingsThemeType = _ref.settingsThemeType,
      children = _ref.children;
  var uiThemeType = localStorage.getItem('ui-theme-type'); // use only for cozy-ui documentation and argos screenshots

  var uiThemeVariant = localStorage.getItem('ui-theme-variant'); // use only for cozy-ui documentation and argos screenshots

  var deviceThemeType = useMediaQuery('(prefers-color-scheme: dark)') ? 'dark' : 'light';
  var filteredSettingsThemeType = ['light', 'dark'].includes(settingsThemeType) ? settingsThemeType : undefined;
  var selfThemeType = uiThemeType || filteredSettingsThemeType || deviceThemeType;
  var selfThemeVariant = uiThemeVariant || variant;
  return /*#__PURE__*/React.createElement(CozyThemeContext.Provider, {
    value: {
      type: selfThemeType,
      variant: selfThemeVariant,
      isLight: selfThemeType === 'light'
    }
  }, /*#__PURE__*/React.createElement(MuiCozyTheme, {
    type: selfThemeType,
    variant: selfThemeVariant
  }, /*#__PURE__*/React.createElement("div", {
    className: cx(className, (_cx = {}, _defineProperty(_cx, "TwakeTheme--".concat(selfThemeType, "-").concat(selfThemeVariant), Boolean(selfThemeVariant)), _defineProperty(_cx, 'u-dc', ignoreItself), _cx))
  }, children)));
};

DumbCozyTheme.propTypes = {
  variant: PropTypes.oneOf(['normal', 'inverted']),

  /** Causes this element's children to appear as if they were direct children of the element's parent, ignoring the element itself. */
  ignoreItself: PropTypes.bool,
  className: PropTypes.string,

  /** Theme type from io.cozy.settings.instance */
  settingsThemeType: PropTypes.oneOf(['light', 'dark', 'auto']),
  children: PropTypes.node
};
export default DumbCozyTheme;
